# Build Docker Image

Use the following steps to run build a GeneFlow docker image:

1. Change to the docker directory:

```
cd geneflow/docker
```


2. Run the build script:

```
./build.sh
```

Your docker image should be tagged with the current version of GeneFlow and the Singularity version.

